<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage Korpo
 * @since Korpo 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function korpo_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( 'None', 'korpo' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

if ( ! function_exists( 'korpo_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function korpo_site_layout() {
        $korpo_site_layout = array(
            'wide'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout' => get_template_directory_uri() . '/assets/images/boxed.png',
            'frame-layout' => get_template_directory_uri() . '/assets/images/framed.png',
        );

        $output = apply_filters( 'korpo_site_layout', $korpo_site_layout );
        return $output;
    }
endif;

if ( ! function_exists( 'korpo_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function korpo_selected_sidebar() {
        $korpo_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'korpo' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar', 'korpo' ),
        );

        $output = apply_filters( 'korpo_selected_sidebar', $korpo_selected_sidebar );

        return $output;
    }
endif;


if ( ! function_exists( 'korpo_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function korpo_sidebar_position() {
        $korpo_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'korpo_sidebar_position', $korpo_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'korpo_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function korpo_pagination_options() {
        $korpo_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'korpo' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'korpo' ),
        );

        $output = apply_filters( 'korpo_pagination_options', $korpo_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'korpo_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function korpo_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'korpo' ),
            'off'       => esc_html__( 'Disable', 'korpo' )
        );
        return apply_filters( 'korpo_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'korpo_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function korpo_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'korpo' ),
            'off'       => esc_html__( 'No', 'korpo' )
        );
        return apply_filters( 'korpo_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'korpo_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function korpo_sortable_sections() {
        $sections = array(
            'about'         => esc_html__( 'About', 'korpo' ),
            'service'       => esc_html__( 'Service', 'korpo' ),
            'project'       => esc_html__( 'Project', 'korpo' ),
            'latest'        => esc_html__( 'Latest', 'korpo' ),
        );
        return apply_filters( 'korpo_sortable_sections', $sections );
    }
endif;