<?php
/**
 * About section
 *
 * This is the template for the content of about section
 *
 * @package Theme Palace
 * @subpackage Korpo
 * @since Korpo 1.0.0
 */
if ( ! function_exists( 'korpo_add_about_section' ) ) :
    /**
    * Add about section
    *
    *@since Korpo 1.0.0
    */
    function korpo_add_about_section() {
    	$options = korpo_get_theme_options();
        // Check if about is enabled on frontpage
        $about_enable = apply_filters( 'korpo_section_status', true, 'about_section_enable' );

        if ( true !== $about_enable ) {
            return false;
        }
        // Get about section details
        $section_details = array();
        $section_details = apply_filters( 'korpo_filter_about_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render about section now.
        korpo_render_about_section( $section_details );
    }
endif;

if ( ! function_exists( 'korpo_get_about_section_details' ) ) :
    /**
    * about section details.
    *
    * @since Korpo 1.0.0
    * @param array $input about section details.
    */
    function korpo_get_about_section_details( $input ) {
        $options = korpo_get_theme_options();

        // Content type.
        $content = array();
        $page_id = ! empty( $options['about_content_page'] ) ? $options['about_content_page'] : '';
        $args = array(
            'post_type'         => 'page',
            'page_id'           => $page_id,
            'posts_per_page'    => 1,
            );                    

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = korpo_trim_content( 35 );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// about section content details.
add_filter( 'korpo_filter_about_section_details', 'korpo_get_about_section_details' );


if ( ! function_exists( 'korpo_render_about_section' ) ) :
  /**
   * Start about section
   *
   * @return string about content
   * @since Korpo 1.0.0
   *
   */
   function korpo_render_about_section( $content_details = array() ) {
        $options = korpo_get_theme_options();
        $about_sub_title = ! empty( $options['about_sub_title'] ) ? $options['about_sub_title'] : '';
        $about_btn_label = ! empty( $options['about_btn_label'] ) ? $options['about_btn_label'] : '';

        if ( empty( $content_details ) ) {
            return;
        } 

        foreach ( $content_details as $content ) : ?>
        	<section id="about-us">
                <div class="about-section-wrapper <?php echo ! empty( $content['image'] ) ? 'has-featured-image' : 'no-featured-image'; ?>">
                    <?php if ( ! empty( $content['image'] ) ) : ?>
                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                        </div><!-- .featured-image -->
                    <?php endif; ?>

                    <div class="entry-container">
                        <div class="section-header">
                            <?php if ( ! empty( $about_sub_title ) ) : ?>
                                <span class="section-subtitle"><?php echo esc_html( $about_sub_title ); ?></span>
                            <?php endif; ?>
                                
                            <h2 class="section-title"><?php echo esc_html( $content['title'] ); ?></h2>
                        </div><!-- .section-header -->

                        <div class="section-content">
                            <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                        </div><!-- .section-content -->
                        
                        <?php if ( ! empty( $about_btn_label ) ) : ?>
                            <div class="more-link">
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn btn-primary"><?php echo esc_html( $about_btn_label ); ?></a>
                            </div><!-- .more-link -->
                        <?php endif; ?>
                    </div><!-- .entry-container -->
                </div>
            </section><!-- #about-us -->
        <?php endforeach;
    }
endif;